library egov_mgramseva_widgets;

import 'dart:async';

import 'package:egov_mgramseva_widgets/widgets/Tost/toast_animation.dart';
import 'package:flutter/material.dart';

class ToastUtils {
  static Timer? toastTimer;
  static OverlayEntry? _overlayEntry;

  static void showCustomToast(
    BuildContext context,
    Function translator,
    String message,
    String type,
  ) {
    if (toastTimer == null || toastTimer!.isActive == false) {
      _overlayEntry = createOverlayEntry(context, translator, message, type);

      Overlay.of(context)!.insert(_overlayEntry!);
      toastTimer = Timer(const Duration(seconds: 10), () {
        if (_overlayEntry != null) {
          _overlayEntry!.remove();
        }
      });
    }
  }

  static OverlayEntry createOverlayEntry(
      BuildContext context, Function translator, String message, String type) {
    return OverlayEntry(
        builder: ((context) => Positioned(
              bottom: 50.0,
              width: MediaQuery.of(context).size.width > 720
                  ? MediaQuery.of(context).size.width / 4
                  : MediaQuery.of(context).size.width,
              left: MediaQuery.of(context).size.width > 720
                  ? MediaQuery.of(context).size.width / 2.55
                  : 0,
              child: (Material(
                elevation: 10.0,
                borderRadius: BorderRadius.circular(10),
                child: Container(
                  padding: const EdgeInsets.only(
                      left: 10, right: 10, top: 13, bottom: 10),
                  decoration: BoxDecoration(
                      color: type == 'ERROR' ? Colors.red : Colors.green[900]),
                  child: Align(
                    alignment: Alignment.center,
                    child: SlideInToastMessageAnimation(Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        Icon(
                          type == 'ERROR'
                              ? Icons.info_outline_rounded
                              : Icons.check_circle_outline_rounded,
                          color: Colors.white,
                        ),
                        Expanded(
                          child: Text(
                            translator(message),
                            textAlign: TextAlign.center,
                            softWrap: true,
                            maxLines: 2,
                            overflow: TextOverflow.ellipsis,
                            style: const TextStyle(
                              fontSize: 18,
                              color: Color(0xFFFFFFFF),
                            ),
                          ),
                        ),
                        GestureDetector(
                          onTap: () {
                            toastTimer!.cancel();
                            _overlayEntry!.remove();
                          },
                          child: const Icon(
                            Icons.close,
                            color: Colors.white,
                          ),
                        )
                      ],
                    )),
                  ),
                ),
              )),
            )));
  }
}
